==> jaguar_auth-0.6.1.tar.gz: lib/src/authenticators/basic.dart <==
part of jaguar_auth.authenticators;

/// BasicAuth performs authentication based on
/// [basic authentication](https://en.wikipedia.org/wiki/Basic_access_authentication).
/// It expects base64 encoded "username:password" pair in "authorization" header
/// with "Basic" scheme.
///
/// Arguments:
/// It uses [sessionManager] to read session information from the request
/// and update session information to response
///
/// It uses [modelManager] to fetch user model for the authentication request
/// and authenticate against the password
///
/// Outputs ans Variables:
/// The authenticated user model is injected into the context as input
///
/// [sessionManager] is added to context variable for usage in route handler or
/// other interceptors
class BasicAuth extends Interceptor {
  /// Session manager is used to read session information from the request
  /// and update session information to response
  final SessionManager sessionManager;

  /// Model manager is used to fetch user model for the authentication request
  /// and authenticate against the password
  final AuthModelManager modelManager;

  /// The key by which authorizationId shall be stored in session data
  final String authorizationIdKey;

  /// Specifies whether the interceptor should create/update the session data
  /// on successful authentication.
  ///
  /// If set to false, session creation and update must be done manually
  final bool manageSession;

  BasicAuth(this.modelManager,
      {this.authorizationIdKey: 'id',
        this.manageSession: true,
        SessionManager sessionManager})
      : sessionManager = sessionManager != null
      ? sessionManager
      : new CookieSessionManager();

  /// Parses the session from request, fetches the user model and authenticates
  /// it against the password.
  ///
  /// On successful login, injects authenticated user model as context input and
  /// session manager as context variable.
  Future<UserBase> pre(Context ctx) async {
    String header = ctx.req.headers.value(HttpHeaders.AUTHORIZATION);
    final basic =
    new AuthHeaderItem.fromHeaderBySchema(header, kBasicAuthScheme);

    if (basic == null) {
      throw new UnAuthorizedError();
    }

    final credentials = _decodeCredentials(basic);
    final usernamePassword = credentials.split(':');

    if (usernamePassword.length != 2) {
      throw new UnAuthorizedError();
    }

    final String username = usernamePassword[0];
    final String password = usernamePassword[1];

    final subject = await modelManager.authenticate(username, password);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    if (manageSession is bool && manageSession) {
      await sessionManager
          .updateSession({authorizationIdKey: subject.authorizationId});
    }

    ctx.addVariable(SessionManager);

    return subject;
  }

  /// Writes session information into the response
  Future<Response> post(Context ctx, Response resp) async {
    return await sessionManager.updateResponse(ctx.req, resp);
  }

  String _decodeCredentials(AuthHeaderItem authHeader) {
    try {
      return new String.fromCharCodes(
          const Base64Codec.urlSafe().decode(authHeader.credentials));
    } on FormatException catch (_) {
      return '';
    }
  }

  static const kBasicAuthScheme = 'Basic';
}

==> jaguar_auth-0.7.0.tar.gz: lib/src/authenticators/basic.dart <==
part of jaguar_auth.authenticators;

/// BasicAuth performs authentication based on
/// [basic authentication](https://en.wikipedia.org/wiki/Basic_access_authentication).
/// It expects base64 encoded "username:password" pair in "authorization" header
/// with "Basic" scheme.
///
/// Arguments:
/// It uses [sessionManager] to read session information from the request
/// and update session information to response
///
/// It uses [modelManager] to fetch user model for the authentication request
/// and authenticate against the password
///
/// Outputs ans Variables:
/// The authenticated user model is injected into the context as input
///
/// [sessionManager] is added to context variable for usage in route handler or
/// other interceptors
class BasicAuth extends Interceptor {
  /// Session manager is used to read session information from the request
  /// and update session information to response
  final SessionManager sessionManager;

  /// Model manager is used to fetch user model for the authentication request
  /// and authenticate against the password
  final AuthModelManager modelManager;

  /// The key by which authorizationId shall be stored in session data
  final String authorizationIdKey;

  /// Specifies whether the interceptor should create/update the session data
  /// on successful authentication.
  ///
  /// If set to false, session creation and update must be done manually
  final bool manageSession;

  BasicAuth(this.modelManager,
      {this.authorizationIdKey: 'id',
      this.manageSession: true,
      SessionManager sessionManager})
      : sessionManager =
            sessionManager != null ? sessionManager : new CookieSession();

  /// Parses the session from request, fetches the user model and authenticates
  /// it against the password.
  ///
  /// On successful login, injects authenticated user model as context input and
  /// session manager as context variable.
  Future<AuthorizationUser> pre(Context ctx) async {
    String header = ctx.req.headers.value(HttpHeaders.AUTHORIZATION);
    final basic =
        new AuthHeaderItem.fromHeaderBySchema(header, kBasicAuthScheme);

    if (basic == null) {
      throw new UnAuthorizedError();
    }

    final credentials = _decodeCredentials(basic);
    final usernamePassword = credentials.split(':');

    if (usernamePassword.length != 2) {
      throw new UnAuthorizedError();
    }

    final String username = usernamePassword[0];
    final String password = usernamePassword[1];

    final subject = await modelManager.authenticate(username, password);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    if (manageSession is bool && manageSession) {
      final data = <String, String>{
        authorizationIdKey: subject.authorizationId
      };
      await sessionManager.createSession(data);
    }

    ctx.addVariable(SessionManager);

    return subject;
  }

  /// Writes session information into the response
  Future<Response> post(Context ctx, Response resp) async {
    return await sessionManager.writeResponse(ctx.req, resp);
  }

  String _decodeCredentials(AuthHeaderItem authHeader) {
    try {
      return new String.fromCharCodes(
          const Base64Codec.urlSafe().decode(authHeader.credentials));
    } on FormatException catch (_) {
      return '';
    }
  }

  static const kBasicAuthScheme = 'Basic';
}
